==> openbazaar-0.0.1.tar.gz: openbazaar-0.0.1/lib/catalog/modules/new_products.php <==
<?php
/*
  $Id: new_products.php,v 1.1.9.1.2.6 2003/11/12 06:49:32 kasugai Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
$currencies = $GLOBALS['currencies'];
if ( (!isset($new_products_category_id)) || ($new_products_category_id == '0') ) {
  $new_products_query = tep_db_query("select p.products_id, p.products_image, p.products_tax_class_id, if(s.status, s.specials_new_products_price, p.products_price) as products_price, p.products_date_added from " . TABLE_PRODUCTS . " p left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id where products_status = '1' order by p.products_date_added desc limit " . MAX_DISPLAY_NEW_PRODUCTS);
} else {
  $new_products_query = tep_db_query("select distinct p.products_id, p.products_image, p.products_tax_class_id, if(s.status, s.specials_new_products_price, p.products_price) as products_price, p.products_date_added from " . TABLE_PRODUCTS . " p left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id, " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c, " . TABLE_CATEGORIES . " c where p.products_id = p2c.products_id and p2c.categories_id = c.categories_id and c.parent_id = '" . (int)$new_products_category_id . "' and p.products_status = '1' order by p.products_date_added desc limit " . MAX_DISPLAY_NEW_PRODUCTS);
}

$num_products = tep_db_num_rows($new_products_query);
$this->assign('num_products', $num_products);

if (0 < $num_products) {
  $this->assign('new_products_title', sprintf(TABLE_HEADING_NEW_PRODUCTS, strftime('%B')));

  $row = 0;
  $col = 0;
  $info_box_contents = array();
  $products_array = array();
  $i=0;
  //mobile or pc
  if(Dino_Browser::is_handy()){
    while ($new_products = tep_db_fetch_array($new_products_query)) {
      $new_products['products_name'] = tep_get_products_name($new_products['products_id']);
      $info_box_contents[$row][$col] = array('align' => 'center',
                                             'params' => 'class="smallText" width="33%" valign="top"',
                                             'text' => '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . $new_products['products_name'] . '</a><br>' . $currencies->display_price($new_products['products_price'], tep_get_tax_rate($new_products['products_tax_class_id'])));
      $products_array[$i] = $info_box_contents[$row][$col]['text'];
	  
      $col ++;
      if ($col > 2) {
        $col = 0;
        $row ++;
      }
      $i++;
    }
  }else{
    while ($new_products = tep_db_fetch_array($new_products_query)) {
      $new_products['products_name'] = tep_get_products_name($new_products['products_id']);
      $info_box_contents[$row][$col] = array('align' => 'center',
                                             'params' => 'class="smallText" width="33%" valign="top"',
                                             'text' => '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $new_products['products_image'], $new_products['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a><br><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . $new_products['products_name'] . '</a><br>' . $currencies->display_price($new_products['products_price'], tep_get_tax_rate($new_products['products_tax_class_id'])));
      $products_array[$i] = $info_box_contents[$row][$col]['text'];
	  
      $col ++;
      if ($col > 2) {
        $col = 0;
        $row ++;
      }
      $i++;
    }

  }
  // new contentBox($info_box_contents);
  $this->assign('new_products_array', $products_array);
}
?>
<!-- new_products_eof //-->

==> openbazaar-0.0.2.tar.gz: openbazaar-0.0.2/lib/catalog/modules/new_products.php <==
<?php
/*
  $Id: new_products.php,v 1.1.9.1.2.7 2003/12/08 09:26:51 shota Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
$currencies = $GLOBALS['currencies'];
// max number of display item
if(Dino_Browser::is_handy()){
  $limit = MAX_DISPLAY_NEW_PRODUCTS_MOBILE;
} else {
  $limit = MAX_DISPLAY_NEW_PRODUCTS;
}
if ( (!isset($new_products_category_id)) || ($new_products_category_id == '0') ) {
  $new_products_query = tep_db_query("select p.products_id, p.products_image, p.products_tax_class_id, if(s.status, s.specials_new_products_price, p.products_price) as products_price, p.products_date_added from " . TABLE_PRODUCTS . " p left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id where products_status = '1' order by p.products_date_added desc limit " . $limit);
} else {
  $new_products_query = tep_db_query("select distinct p.products_id, p.products_image, p.products_tax_class_id, if(s.status, s.specials_new_products_price, p.products_price) as products_price, p.products_date_added from " . TABLE_PRODUCTS . " p left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id, " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c, " . TABLE_CATEGORIES . " c where p.products_id = p2c.products_id and p2c.categories_id = c.categories_id and c.parent_id = '" . (int)$new_products_category_id . "' and p.products_status = '1' order by p.products_date_added desc limit " . $limit);
}

$num_products = tep_db_num_rows($new_products_query);
$this->assign('num_products', $num_products);

if (0 < $num_products) {
  $this->assign('new_products_title', sprintf(TABLE_HEADING_NEW_PRODUCTS, strftime('%B')));

  $row = 0;
  $col = 0;
  $info_box_contents = array();
  $products_array = array();
  $i=0;
  //mobile or pc
  if(Dino_Browser::is_handy()){
    while ($new_products = tep_db_fetch_array($new_products_query)) {
      $new_products['products_name'] = tep_get_products_name($new_products['products_id']);
      $info_box_contents[$row][$col] = array('align' => 'center',
                                             'params' => 'class="smallText" width="33%" valign="top"',
                                             'text' => '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . $new_products['products_name'] . '</a><br>' . $currencies->display_price($new_products['products_price'], tep_get_tax_rate($new_products['products_tax_class_id'])));
      $products_array[$i] = $info_box_contents[$row][$col]['text'];
	  
      $col ++;
      if ($col > 2) {
        $col = 0;
        $row ++;
      }
      $i++;
    }
  }else{
    while ($new_products = tep_db_fetch_array($new_products_query)) {
      $new_products['products_name'] = tep_get_products_name($new_products['products_id']);
      $info_box_contents[$row][$col] = array('align' => 'center',
                                             'params' => 'class="smallText" width="33%" valign="top"',
                                             'text' => '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $new_products['products_image'], $new_products['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a><br><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . $new_products['products_name'] . '</a><br>' . $currencies->display_price($new_products['products_price'], tep_get_tax_rate($new_products['products_tax_class_id'])));
      $products_array[$i] = $info_box_contents[$row][$col]['text'];
	  
      $col ++;
      if ($col > 2) {
        $col = 0;
        $row ++;
      }
      $i++;
    }

  }
  // new contentBox($info_box_contents);
  $this->assign('new_products_array', $products_array);
}
?>
<!-- new_products_eof //-->
